@@ -583,6 +583,7 @@ class VirtualEnv(object):
         ignore_ret=False,
         returnout=False,
         env=None,
+        capture_err=True,
     ):
         if env is None:
             env = self._get_os_environ(is_test_command=is_test_command)
@@ -595,7 +596,17 @@ class VirtualEnv(object):
         reporter.verbosity2("setting PATH={}".format(env["PATH"]))
 
         # get command
-        args[0] = self.getcommandpath(args[0], venv, cwd)
+        try:
+            args[0] = self.getcommandpath(args[0], venv, cwd)
+        except tox.exception.InvocationError:
+            if ignore_ret:
+                self.status = getattr(self, "status", 0)
+                msg = "command not found but explicitly ignored"
+                reporter.warning("{}\ncmd: {}".format(msg, args[0]))
+                return ""  # in case it's returnout
+            else:
+                raise
+
         if sys.platform != "win32" and "TOX_LIMITED_SHEBANG" in os.environ:
             args = prepend_shebang_interpreter(args)
 
@@ -608,6 +619,7 @@ class VirtualEnv(object):
             ignore_ret=ignore_ret,
             returnout=returnout,
             report_fail=not is_test_command,
+            capture_err=capture_err,
         )
 
     def setupenv(self):
